<?php
/**
 * bluepress functions and definitions
 *
 * Sets up the theme and provides some helper functions. Some helper functions
 * are used in the theme as custom template tags. Others are attached to action and
 * filter hooks in WordPress to change core functionality.
 *
 * The first function, bluepress_setup(), sets up the theme by registering support
 * for various features in WordPress, such as post thumbnails, navigation menus, and the like.
 *
 * When using a child theme (see http://codex.wordpress.org/Theme_Development and
 * http://codex.wordpress.org/Child_Themes), you can override certain functions
 * (those wrapped in a function_exists() call) by defining them first in your child theme's
 * functions.php file. The child theme's functions.php file is included before the parent
 * theme's file, so the child theme functions would be used.
 *
 * Functions that are not pluggable (not wrapped in function_exists()) are instead attached
 * to a filter or action hook. The hook can be removed by using remove_action() or
 * remove_filter() and you can attach your own function to the hook.
 *
 * We can remove the parent theme's hook only after it is attached, which means we need to
 * wait until setting up the child theme:
 *
 * <code>
 * add_action( 'after_setup_theme', 'my_child_theme_setup' );
 * function my_child_theme_setup() {
 *     // We are providing our own filter for excerpt_length (or using the unfiltered value)
 *     remove_filter( 'excerpt_length', 'bluepress_excerpt_length' );
 *     ...
 * }
 * </code>
 *
 * For more information on hooks, actions, and filters, see http://codex.wordpress.org/Plugin_API.
 *
 * @package WordPress
 * @subpackage Bluepress
 */

/** Tell WordPress to run bluepress_setup() when the 'after_setup_theme' hook is run. */
add_action( 'after_setup_theme', 'bluepress_setup' );

if ( ! function_exists( 'bluepress_setup' ) ):
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which runs
 * before the init hook. The init hook is too late for some features, such as indicating
 * support post thumbnails.
 *
 * To override bluepress_setup() in a child theme, add your own bluepress_setup to your child theme's
 * functions.php file.
 *
 * @uses add_theme_support() To add support for post thumbnails and automatic feed links.
 * @uses register_nav_menus() To add support for navigation menus.
 * @uses add_custom_background() To add support for a custom background.
 * @uses set_post_thumbnail_size() To set a custom post thumbnail size.
 */
function bluepress_setup() {

	// This theme uses post thumbnails
	add_theme_support( 'post-thumbnails' );

	// Add default posts and comments RSS feed links to head
	add_theme_support( 'automatic-feed-links' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => __( 'Primary Navigation', 'bluepress' ),
	) );

	// This theme allows users to set a custom background
	add_custom_background();

	// We'll be using post thumbnails for custom header images on posts and pages.
	// We want them to be 600 pixels wide by 600 pixels tall.
	// Larger images will be auto-cropped to fit, smaller ones will be ignored. See header.php.
	set_post_thumbnail_size( 640, 640, true );
	
	// Register custom widgets
	require_once(TEMPLATEPATH . '/library/functions/widgets.php');
	
	// Remove some defaults
	remove_action('wp_head', 'start_post_rel_link');
	remove_action('wp_head', 'index_rel_link');
	remove_action('wp_head', 'adjacent_posts_rel_link');
	remove_action('wp_head', 'next_post_rel_link');
	remove_action('wp_head', 'previous_post_rel_link');
}
endif;

/**
 * Get Theme Info - Credits: Joern Kretzschmar & Thematic
 */
 
$themeData = get_theme_data(TEMPLATEPATH . '/style.css');
$version = trim($themeData['Version']);
if(!$version)
	$version = "unknown";

/**
 * Set Theme Info in Constant
 */
 
define('THEMENAME', $themeData['Title']);
define('THEMEVERSION', $version);

/**
 * Makes some changes to the <title> tag, by filtering the output of wp_title().
 *
 * If we have a site description and we're viewing the home page or a blog posts
 * page (when using a static front page), then we will add the site description.
 *
 * If we're viewing a search result, then we're going to recreate the title entirely.
 * We're going to add page numbers to all titles as well, to the middle of a search
 * result title and the end of all other titles.
 *
 * The site title also gets added to all titles.
 *
 * @param string $title Title generated by wp_title()
 * @param string $separator The separator passed to wp_title(). Twenty Ten uses a
 * 	vertical bar, "|", as a separator in header.php.
 * @return string The new title, ready for the <title> tag.
 */
function bluepress_filter_wp_title( $title, $separator ) {
	// The $paged global variable contains the page number of a listing of posts.
	// The $page global variable contains the page number of a single post that is paged.
	// We'll display whichever one applies, if we're not looking at the first page.
	global $paged, $page;

	if ( is_search() ) {
		// If we're a search, let's start over:
		$title = sprintf( __( 'Search results for %s', 'bluepress' ), '"' . get_search_query() . '"' );
		// Add a page number if we're on page 2 or more:
		if ( $paged >= 2 )
			$title .= " $separator " . sprintf( __( 'Page %s', 'bluepress' ), $paged );
		// Add the site name to the end:
		$title .= " $separator " . get_bloginfo( 'name', 'display' );
		// We're done. Let's send the new title back to wp_title():
		return $title;
	}

	// Otherwise, let's start by adding the site name to the end:
	$title .= get_bloginfo( 'name', 'display' );

	// If we have a site description and we're on the home/front page, add the description:
	$site_description = get_bloginfo( 'description', 'display' );
	if ( $site_description && ( is_home() || is_front_page() ) )
		$title .= " $separator " . $site_description;

	// Add a page number if necessary:
	if ( $paged >= 2 || $page >= 2 )
		$title .= " $separator " . sprintf( __( 'Page %s', 'bluepress' ), max( $paged, $page ) );

	// Return the new title to wp_title():
	return $title;
}
add_filter( 'wp_title', 'bluepress_filter_wp_title', 10, 2 );

/**
 * Replace wp version to theme version.
 */

function bluepress_wp_generator()
{
	echo '<meta name="generator" content="'.THEMENAME." ".THEMEVERSION.'" />';
}
add_filter('the_generator','bluepress_wp_generator');

/**
 * SEO: Create meta data tags.
 */
function bluepress_create_metadata() {
	if(is_home()) {
		if ( get_option('bluepress_meta_description') <> "" ) { echo '<meta name="description" content="'.stripslashes(get_option('bluepress_meta_description')).'" />' . "\n"; }
		if ( get_option('bluepress_meta_keywords') <> "" ) { echo '<meta name="keywords" content="'.stripslashes(get_option('bluepress_meta_keywords')).'" />' . "\n"; }
		if ( get_option('bluepress_meta_author') <> "" ) { echo '<meta name="author" content="'.stripslashes(get_option('bluepress_meta_author')).'" />' . "\n"; }
	}
}

/**
 * SEO: Create robots.
 */
function bluepress_create_robots() {
	global $paged;

	if((is_home() && ($paged < 2 )) || is_front_page() || is_single() || is_page() || is_attachment()) {
		$content .= "<meta name=\"robots\" content=\"index,follow\" />";
	} elseif (is_search()) {
		$content .= "<meta name=\"robots\" content=\"noindex,nofollow\" />";
	} else {	
		$content .= "<meta name=\"robots\" content=\"noindex,follow\" />";
	}
	$content .= "\n";
	if (get_option('blog_public')) {
		echo apply_filters('bluepress_create_robots', $content);
	}
}
 
/**
 * SEO: Create canonical url.
 */
function bluepress_canonical_url() {
	if(get_option("bluepress_canonical") <> "") {
		if ( is_singular() ) {
			$canonical_url .= '<link rel="canonical" href="' . get_permalink() . '" />';
			$canonical_url .= "\n";        
			echo apply_filters('bluepress_canonical_url', $canonical_url);
		}
	}
}

/**
 * Load required javascript to wp_head().
 */
function bluepress_head_scripts() {
	$scriptdir_start .= '<script type="text/javascript" src="';
	$scriptdir_start .= get_bloginfo('template_directory');
	$scriptdir_start .= '/library/scripts/';
	$scriptdir_end = '"></script>';
	$scripts .= $scriptdir_start . 'jquery.min.js' . $scriptdir_end . "\n";
	$scripts .= $scriptdir_start . 'hoverIntent.js' . $scriptdir_end . "\n";
	$scripts .= $scriptdir_start . 'superfish.js' . $scriptdir_end . "\n";
	$scripts .= $scriptdir_start . 'supersubs.js' . $scriptdir_end . "\n";
	$dropdown_options = $scriptdir_start . 'dropdowns.js' . $scriptdir_end . "\n";
	$scripts = $scripts . apply_filters('dropdown_options', $dropdown_options);
	$scripts .= $scriptdir_start . 'loopedslider.js' . $scriptdir_end . "\n";
	
	// Inset custom header script - via theme option
	if(get_option("bluepress_enable_headercode") <> "") {
		$scripts .= get_option("bluepress_headercode") . "\n";
	}
	
	// Print filtered scripts
	print apply_filters('bluepress_head_scripts', $scripts);
	
}
add_action('wp_head','bluepress_head_scripts');

/**
 * Inset custom footer script to wp_footer().
 */
function bluepress_foot_scripts() {
	if(get_option("bluepress_enable_footercode") == "enable") {
		$scripts .= get_option('bluepress_footercode');
	}
	
	// Print filtered scripts
	print apply_filters('bluepress_foot_scripts', $scripts);
}
add_action('wp_footer','bluepress_foot_scripts');

/**
 * Get our wp_nav_menu() fallback, wp_page_menu(), to show a home link.
 *
 * To override this in a child theme, remove the filter and optionally add
 * your own function tied to the wp_page_menu_args filter hook.
 */
function bluepress_page_menu_args( $args ) {
	$args['show_home'] = true;
	return $args;
}
add_filter( 'wp_page_menu_args', 'bluepress_page_menu_args' );

/**
 * Add ID and CLASS attributes to the first <ul> occurence in wp_page_menu.
 */
function bluepress_add_menuclass($ulclass) {
	return preg_replace('/<ul>/', '<ul class="sf-menu">', $ulclass, 1);
}
add_filter('wp_page_menu','bluepress_add_menuclass');

/**
 * Add the proper class of menu container if wp_nav_menu is not set.
 */
function bluepress_proper_containerclass($containerclass) {
	return preg_replace('/<div class="sf-menu">/', '<div class="menu">', $containerclass, 1);
}
add_filter('wp_page_menu','bluepress_proper_containerclass');

/**
 * Sets the post excerpt length to 40 characters.
 *
 * To override this length in a child theme, remove the filter and add your own
 * function tied to the excerpt_length filter hook.
 *
 * @return int
 */
function bluepress_excerpt_length( $length ) {
	return 30;
}
add_filter( 'excerpt_length', 'bluepress_excerpt_length' );

/**
 * Returns a "Continue Reading" link for excerpts
 *
 * @return string "Continue Reading" link
 */
function bluepress_continue_reading_link() {
	return ' <a href="'. get_permalink() . '">' . __( 'Continue reading <span class="meta-nav">&rarr;</span>', 'bluepress' ) . '</a>';
}

/**
 * Replaces "[...]" (appended to automatically generated excerpts) with an ellipsis and bluepress_continue_reading_link().
 *
 * To override this in a child theme, remove the filter and add your own
 * function tied to the excerpt_more filter hook.
 *
 * @return string An ellipsis
 */
function bluepress_auto_excerpt_more( $more ) {
	return ' &hellip;' . bluepress_continue_reading_link();
}
add_filter( 'excerpt_more', 'bluepress_auto_excerpt_more' );

/**
 * Adds a pretty "Continue Reading" link to custom post excerpts.
 *
 * To override this link in a child theme, remove the filter and add your own
 * function tied to the get_the_excerpt filter hook.
 *
 * @return string Excerpt with a pretty "Continue Reading" link
 */
function bluepress_custom_excerpt_more( $output ) {
	if ( has_excerpt() && ! is_attachment() ) {
		$output .= bluepress_continue_reading_link();
	}
	return $output;
}
add_filter( 'get_the_excerpt', 'bluepress_custom_excerpt_more' );

/**
 * Remove inline styles printed when the gallery shortcode is used.
 *
 * Galleries are styled by the theme in Twenty Ten's style.css.
 *
 * @return string The gallery style filter, with the styles themselves removed.
 */
function bluepress_remove_gallery_css( $css ) {
	return preg_replace( "#<style type='text/css'>(.*?)</style>#s", '', $css );
}
add_filter( 'gallery_style', 'bluepress_remove_gallery_css' );

if ( ! function_exists( 'bluepress_comment' ) ) :
/**
 * Template for comments and pingbacks.
 *
 * To override this walker without modifying the comments template
 * simply create your own bluepress_comment(), and that function will be used instead.
 *
 * Used as a callback by wp_list_comments() for displaying the comments.
 */
function bluepress_comment( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	switch($comment->comment_type){
		case '':
?>
	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
    	<div id="comment-<?php comment_ID(); ?>">
            <div class="comment_meta commentmetadata">
                <span class="avatar"><?php echo get_avatar( $comment, 40 ); ?></span>
                <span class="comment_author vcard fn"><?php echo get_comment_author_link(); ?></span>
                <span class="comment_time"><?php echo sprintf(__('%1$s at %2$s'), get_comment_date(), get_comment_time()); ?></span>
            </div>
            <div class="comment_body">
                <p><?php comment_text(); ?></p>
                <p class="reply"><?php comment_reply_link( array_merge( $args, array( 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?></p>
            </div>
		</div>
        
        
    
<?php		break;
		case 'pingback':
			break;
		case 'trackback':
			break;
	}
}
endif;
/**
 * Used to count comments and pingbacks.
 */
function count_comment($count, $type = 'comments'){
	if($type == 'comments'){
		$text_singular = "comment";
		$text_plural = "comments";
	} elseif($type == 'trackbacks') {
		$text_singular = "trackback";
		$text_plural = "trackbacks";
	}
	
	if($count == 0) {
		$comment_text = $count . " " . $text_plural;
	}
	elseif($count == 1) {
		$comment_text = $count . " " . $text_singular;
	}
	elseif($count > 1) {
		$comment_text = $count . " " . $text_plural;
	}
	
	echo $comment_text;
}

/**
 * Register widgetized areas, including two sidebars and four widget-ready columns in the footer.
 *
 * To override bluepress_widgets_init() in a child theme, remove the action hook and add your own
 * function tied to the init hook.
 *
 * @uses register_sidebar
 */
function bluepress_widgets_init() {
	register_sidebar( array(
		'name' => __( 'Primary Widget Area', 'bluepress' ),
		'id' => 'primary-widget-area',
		'description' => __( 'The primary widget area', 'bluepress' ),
		'before_widget' => '<li id="%1$s" class="widget-container %2$s">',
		'after_widget' => '</li>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );

	// Located in the footer. Empty by default.
	register_sidebar( array(
		'name' => __( 'First Footer Widget Area', 'bluepress' ),
		'id' => 'first-footer-widget-area',
		'description' => __( 'The first footer widget area', 'bluepress' ),
		'before_widget' => '<li id="%1$s" class="widget-container %2$s">',
		'after_widget' => '</li>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );

	// Located in the footer. Empty by default.
	register_sidebar( array(
		'name' => __( 'Second Footer Widget Area', 'bluepress' ),
		'id' => 'second-footer-widget-area',
		'description' => __( 'The second footer widget area', 'bluepress' ),
		'before_widget' => '<li id="%1$s" class="widget-container %2$s">',
		'after_widget' => '</li>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );

	// Located in the footer. Empty by default.
	register_sidebar( array(
		'name' => __( 'Third Footer Widget Area', 'bluepress' ),
		'id' => 'third-footer-widget-area',
		'description' => __( 'The third footer widget area', 'bluepress' ),
		'before_widget' => '<li id="%1$s" class="widget-container %2$s">',
		'after_widget' => '</li>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );
}
/** Register sidebars by running bluepress_widgets_init() on the widgets_init hook. */
add_action( 'widgets_init', 'bluepress_widgets_init' );

/**
 * Removes the default styles that are packaged with the Recent Comments widget.
 *
 * To override this in a child theme, remove the filter and optionally add your own
 * function tied to the widgets_init action hook.
 */
function bluepress_remove_recent_comments_style() {
	global $wp_widget_factory;
	remove_action( 'wp_head', array( $wp_widget_factory->widgets['WP_Widget_Recent_Comments'], 'recent_comments_style' ) );
}
add_action( 'widgets_init', 'bluepress_remove_recent_comments_style' );



if ( ! function_exists( 'bluepress_posted_on' ) ) :
/**
 * Prints HTML with meta information for the current post—date/time and author.
 */
function bluepress_posted_on() {
	$category = get_the_category($post->ID);
	if( count($category) > 0 ) {
		$category = 'in <a href="'.get_category_link($category[0]->term_id).'">' .$category[0]->name. '</a>';
	} else { $category = ''; }
	printf( __( '<span class="meta-sep">Posted by</span> %1$s %2$s <span class="%3$s"> on </span> %4$s', 'bluepress' ),
		sprintf( '<span class="author vcard"><a class="url fn n" href="%1$s" title="%2$s">%3$s</a></span>',
			get_author_posts_url( get_the_author_meta( 'ID' ) ),
			sprintf( esc_attr__( 'View all posts by %s', 'bluepress' ), get_the_author() ),
			get_the_author()
		),
		$category,
		'meta-prep meta-prep-author',
		sprintf( '<span class="entry-date"><abbr class="published" title="%1$s">%2$s</abbr></span>',
			esc_attr( get_the_time() ),
			get_the_date()
		)
	); ?>
    <span class="comment_count"><a href="<?php comments_link(); ?>"><?php comments_number('0', '1', '%'); ?></a></span>
<?php }
endif;

if ( ! function_exists( 'bluepress_posted_in' ) ) :
/**
 * Prints HTML with meta information for the current post (category, tags and permalink).
 */
function bluepress_posted_in() {
	// Retrieves tag list of current post, separated by commas.
	$tag_list = get_the_tag_list( '', ', ' );
	if ( $tag_list ) {
		$posted_in = __( 'Posted in %1$s and tagged %2$s. Bookmark the <a href="%3$s" title="Permalink to %4$s" rel="bookmark">permalink</a>.', 'bluepress' );
	} elseif ( is_object_in_taxonomy( get_post_type(), 'category' ) ) {
		$posted_in = __( 'Posted in %1$s. Bookmark the <a href="%3$s" title="Permalink to %4$s" rel="bookmark">permalink</a>.', 'bluepress' );
	} else {
		$posted_in = __( 'Bookmark the <a href="%3$s" title="Permalink to %4$s" rel="bookmark">permalink</a>.', 'bluepress' );
	}
	// Prints the string, replacing the placeholders.
	printf(
		$posted_in,
		get_the_category_list( ', ' ),
		$tag_list,
		get_permalink(),
		the_title_attribute( 'echo=0' )
	);
}
endif;

/**
 * Handle IE8 compatibility.
 */

function bluepress_pagenavi() {
    global $wp_rewrite, $wp_query;
    $wp_query->query_vars['paged'] > 1 ? $current = $wp_query->query_vars['paged'] : $current = 1;
    $pagination = array(
        'base' => @add_query_arg('paged','%#%'),
        'format' => '',
        'total' => $wp_query->max_num_pages,
        'current' => $current,
        'prev_text' => __('« Previous'),
        'next_text' => __('Next »'),
        'end_size' => 1,
        'mid_size' => 2,
        'show_all' => true,
        'type' => 'html'
    );
    if ( $wp_rewrite->using_permalinks() )
            $pagination['base'] = user_trailingslashit( trailingslashit( remove_query_arg( 's', get_pagenum_link( 1 ) ) ) . 'page/%#%/', 'paged' );
    if ( !empty( $wp_query->query_vars['s'] ) )
            $pagination['add_args'] = array( 's' => get_query_var( 's' ) );
    echo '<div class="navigation clearfix"><span class="pages">Pages: </span>' . paginate_links( $pagination ) . '</div>';
}

/**
 * Handle IE8 compatibility.
 */
if (!is_admin())
	header('X-UA-Compatible: IE=EmulateIE7');
	
/**
 * Load theme options.
 */
$themename = "Bluepress";
$pre = "bluepress";
$settings_navigation = array('general', 'seo', 'layout', 'advertisement', 'integration', 'support');
	
$options = array();
	
$functions_path = TEMPLATEPATH . '/library/admin/';
	
define( OPTION_FILES, 'base.php' );
	
function startit() {
	global $themename, $options, $pre, $functions_path;
			
	if (function_exists('add_menu_page')) {
		$basename = basename( OPTION_FILES );
		add_theme_page( $themename." Options", "$themename Theme Options", 'edit_themes', 'base.php', 'build_options');
	}
}
	
function build_options() {
	global $themename, $pre, $functions_path, $options, $settings_navigation;
	$page = $_GET["page"];
	include( $functions_path . '/options/' . $page );
	if ( isset($_GET['page']) && $_GET['page'] == "base.php" ) {
		if ( isset($_REQUEST['action']) ) {
			if ( 'save' == $_REQUEST['action'] ) {
				foreach ($options as $value) {
					if( isset( $value['id'] ) ) { 
						if( isset( $_REQUEST[ $value['id'] ] ) ) {
							if ($value['type'] == 'textarea' || $value['type'] == 'text') update_option( $value['id'], stripslashes($_REQUEST[$value['id']]) );
							elseif ($value['type'] == 'select' || $value['type'] == 'select-switch') update_option( $value['id'], htmlspecialchars($_POST[$value['id']]) );
							else update_option( $value['id'], $_POST[$value['id']] );
						}
					}
				}
				header("Location: themes.php?page=base.php&saved=true");
				die;	
			} else if( 'reset' == $_REQUEST['action'] ) {
				foreach ($options as $value) {
					if (isset($value['id'])) {
						delete_option( $value['id'] );
						if (isset($value['std'])) $$value['id'] = $value['std'];
					}
				}
				header("Location:themes.php?page=base.php&reset=true");
				die;
			}
		}
	}
	if(isset($_GET['reset']) && $_GET['reset'] == true) echo '<div id="action_info">' .$themename. ' configiruation has been reset back to defaults.</div>';
	include( $functions_path . '/build.php' );
}
	
function build_admin_head() {
	global $functions_path;
	
	if ('themes.php' == basename($_SERVER['SCRIPT_FILENAME'])) {
		echo '<link rel="stylesheet" type="text/css" href="'.get_bloginfo('template_directory').'/library/admin/build.css" media="screen" />';
		?>
        <script type="text/javascript" src="<?php bloginfo("template_directory"); ?>/library/admin/js/epanel.js"></script>
		<script type="text/javascript" language="javascript">
			jQuery(document).ready(function(){
				//= Tipsy
				jQuery('select, input[type="text"], textarea').tipsy({gravity: 'n'});
				
				//facebox
				jQuery('a[rel*=facebox]').facebox({
					loadingImage : '<?php bloginfo("template_directory"); ?>/library/admin/images/loading.gif',
					closeImage: '<?php bloginfo("template_directory"); ?>/library/admin/images/closebox.png'
				});
				//= Navigation Tabs
				var navContainer = jQuery("#epanel #navigation").find("a");
				var optContainer = jQuery("#epanel #container").find(".primary-container");
				
				optContainer.hide().filter(':first').show();
				jQuery("#navigation a").click(function(){
					optContainer.hide();
					optContainer.filter(this.hash).css("margin-top","50px");
					optContainer.filter(this.hash).animate({ 'margin-top': '0px', opacity: 'show' }, "normal");
					navContainer.parent().removeClass("nav-selected");
					jQuery(this).parent().addClass("nav-selected");
					jQuery(this).parent()
					return false;
				}).filter(':first').click();
				
				jQuery('#defaults_button').click(function(e){
					var reset_settings = confirm("Are your sure to reset the settings?");
					if(!reset_settings){return false;}
					jQuery('#action').val("reset");
					
					var options_fromform = jQuery('#buildform').serialize();
					e.preventDefault();
					jQuery.facebox(function(){
						jQuery.ajax({
							type: "POST",
							url: "themes.php?page=base.php",
							data: options_fromform,
							success: function(response){
								window.location.href = "themes.php?page=base.php&reset=true";
							},
							error: function(err){
								jQuery.facebox("Error!");
							}
						});	
					});
				});	
				jQuery('#save_button').click(function(e){
					var options_fromform = jQuery('#buildform').serialize();
					var save_button = jQuery(this);
					
					e.preventDefault();
					jQuery.facebox(function(){
						jQuery.ajax({
							type: "POST",
							url: "themes.php?page=base.php",
							data: options_fromform,
							success: function(response){
								jQuery.facebox('Settings Saved!');
								setTimeout(function(){
									jQuery(document).trigger('close.facebox');
								},1500);
							},
							error: function(err){
								jQuery.facebox("Error!");
							}
						});
					});	
					return false;
				});
			});
		</script>
		<?php
	}  //end of theme accesibility mode
}
	
add_action('admin_menu', 'startit');
add_action('admin_head', 'build_admin_head');
?>